@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtTest/QtTest>
 #include <QtCharts/QBarSeries>
@@ -191,7 +165,7 @@ void tst_QBarSeries::remove_data()
 
 void tst_QBarSeries::remove()
 {
-    int count = m_testSets.count();
+    int count = m_testSets.size();
     QVERIFY(m_barseries_with_sets->count() == count);
 
     // Try to remove null pointer (should not remove, should not crash)
@@ -237,19 +211,19 @@ void tst_QBarSeries::take_data()
 
 void tst_QBarSeries::take()
 {
-    int count = m_testSets.count();
+    int count = m_testSets.size();
     QVERIFY(m_barseries_with_sets->count() == count);
 
     QSignalSpy countSpy(m_barseries_with_sets,SIGNAL(countChanged()));
     QSignalSpy removedSpy(m_barseries_with_sets,SIGNAL(barsetsRemoved(QList<QBarSet*>)));
 
-    for (int i=0; i<m_testSets.count(); i++) {
+    for (int i=0; i<m_testSets.size(); i++) {
         QBarSet* set = m_testSets.at(i);
         bool success = m_barseries_with_sets->take(set);
         QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
         QVERIFY(success);
-        TRY_COMPARE(countSpy.count(),1);
-        TRY_COMPARE(removedSpy.count(),1);
+        TRY_COMPARE(countSpy.size(),1);
+        TRY_COMPARE(removedSpy.size(),1);
 
         QList<QVariant> removedSpyArg = removedSpy.takeFirst();
         QList<QBarSet*> removedSets = qvariant_cast<QList<QBarSet*> > (removedSpyArg.at(0));
@@ -317,7 +291,7 @@ void tst_QBarSeries::count_data()
 void tst_QBarSeries::count()
 {
     QVERIFY(m_barseries->count() == 0);
-    QVERIFY(m_barseries_with_sets->count() == m_testSets.count());
+    QVERIFY(m_barseries_with_sets->count() == m_testSets.size());
 }
 
 void tst_QBarSeries::barSets_data()
@@ -327,12 +301,12 @@ void tst_QBarSeries::barSets_data()
 
 void tst_QBarSeries::barSets()
 {
-    QVERIFY(m_barseries->barSets().count() == 0);
+    QVERIFY(m_barseries->barSets().size() == 0);
 
     QList<QBarSet*> sets = m_barseries_with_sets->barSets();
-    QVERIFY(sets.count() == m_testSets.count());
+    QVERIFY(sets.size() == m_testSets.size());
 
-    for (int i=0; i<m_testSets.count(); i++) {
+    for (int i=0; i<m_testSets.size(); i++) {
         QVERIFY(sets.at(i) == m_testSets.at(i));
     }
 }
@@ -371,13 +345,13 @@ void tst_QBarSeries::setLabelsFormat()
 
     QString format("(@value)");
     m_barseries->setLabelsFormat(format);
-    TRY_COMPARE(labelsFormatSpy.count(), 1);
+    TRY_COMPARE(labelsFormatSpy.size(), 1);
     QList<QVariant> arguments = labelsFormatSpy.takeFirst();
     QVERIFY(arguments.at(0).toString() == format);
     QCOMPARE(m_barseries->labelsFormat(), format);
 
     m_barseries->setLabelsFormat(QString());
-    TRY_COMPARE(labelsFormatSpy.count(), 1);
+    TRY_COMPARE(labelsFormatSpy.size(), 1);
     arguments = labelsFormatSpy.takeFirst();
     QVERIFY(arguments.at(0).toString() == QString());
     QCOMPARE(m_barseries->labelsFormat(), QString());
@@ -390,28 +364,28 @@ void tst_QBarSeries::setLabelsPosition()
     QCOMPARE(m_barseries->labelsPosition(), QBarSeries::LabelsCenter);
 
     m_barseries->setLabelsPosition(QBarSeries::LabelsInsideEnd);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     QList<QVariant> arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
                 == QBarSeries::LabelsInsideEnd);
     QCOMPARE(m_barseries->labelsPosition(), QBarSeries::LabelsInsideEnd);
 
     m_barseries->setLabelsPosition(QBarSeries::LabelsInsideBase);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
             == QBarSeries::LabelsInsideBase);
     QCOMPARE(m_barseries->labelsPosition(), QBarSeries::LabelsInsideBase);
 
     m_barseries->setLabelsPosition(QBarSeries::LabelsOutsideEnd);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
             == QBarSeries::LabelsOutsideEnd);
     QCOMPARE(m_barseries->labelsPosition(), QBarSeries::LabelsOutsideEnd);
 
     m_barseries->setLabelsPosition(QBarSeries::LabelsCenter);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
             == QBarSeries::LabelsCenter);
@@ -425,7 +399,7 @@ void tst_QBarSeries::setLabelsAngle()
     QCOMPARE(m_barseries->labelsAngle(), 0.0);
 
     m_barseries->setLabelsAngle(55.0);
-    TRY_COMPARE(labelsAngleSpy.count(), 1);
+    TRY_COMPARE(labelsAngleSpy.size(), 1);
     QList<QVariant> arguments = labelsAngleSpy.takeFirst();
     QVERIFY(arguments.at(0).value<qreal>() == 55.0);
     QCOMPARE(m_barseries->labelsAngle(), 55.0);
@@ -438,7 +412,7 @@ void tst_QBarSeries::setLabelsPrecision()
     QCOMPARE(m_barseries->labelsPrecision(), 6);
 
     m_barseries->setLabelsPrecision(9);
-    TRY_COMPARE(labelsPrecisionSpy.count(), 1);
+    TRY_COMPARE(labelsPrecisionSpy.size(), 1);
     QList<QVariant> arguments = labelsPrecisionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<int>() == 9);
     QCOMPARE(m_barseries->labelsPrecision(), 9);
@@ -452,15 +426,15 @@ void tst_QBarSeries::opacity()
 
     m_barseries->setOpacity(0.5);
     QCOMPARE(m_barseries->opacity(), 0.5);
-    QCOMPARE(opacitySpy.count(), 1);
+    QCOMPARE(opacitySpy.size(), 1);
 
     m_barseries->setOpacity(0.0);
     QCOMPARE(m_barseries->opacity(), 0.0);
-    QCOMPARE(opacitySpy.count(), 2);
+    QCOMPARE(opacitySpy.size(), 2);
 
     m_barseries->setOpacity(1.0);
     QCOMPARE(m_barseries->opacity(), 1.0);
-    QCOMPARE(opacitySpy.count(), 3);
+    QCOMPARE(opacitySpy.size(), 3);
 }
 
 void tst_QBarSeries::mouseclicked_data()
@@ -529,9 +503,9 @@ void tst_QBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -547,9 +521,9 @@ void tst_QBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -565,9 +539,9 @@ void tst_QBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(4).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -583,9 +557,9 @@ void tst_QBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -601,9 +575,9 @@ void tst_QBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(3).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -619,9 +593,9 @@ void tst_QBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(5).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -716,16 +690,16 @@ void tst_QBarSeries::mousehovered()
 // move mouse to left border
     QTest::mouseMove(view.viewport(), QPoint(0, layout.at(0).center().y()));
     QTest::qWait(5000);
-    QCOMPARE(seriesIndexSpy.count(), 0);
-    QCOMPARE(setIndexSpy1.count(), 0);
-    QCOMPARE(setIndexSpy2.count(), 0);
+    QCOMPARE(seriesIndexSpy.size(), 0);
+    QCOMPARE(setIndexSpy1.size(), 0);
+    QCOMPARE(setIndexSpy2.size(), 0);
 
 //=======================================================================
 // move mouse to just inside left border to account for labels
     QTest::mouseMove(view.viewport(), QPoint(layout.at(0).x() + 1, layout.at(0).y() + 1));
-    QTRY_COMPARE(seriesIndexSpy.count(), 1);
-    QTRY_COMPARE(setIndexSpy1.count(), 1);
-    QTRY_COMPARE(setIndexSpy2.count(), 0);
+    QTRY_COMPARE(seriesIndexSpy.size(), 1);
+    QTRY_COMPARE(setIndexSpy1.size(), 1);
+    QTRY_COMPARE(setIndexSpy2.size(), 0);
 
     QList<QVariant> seriesIndexSpyArg = seriesIndexSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesIndexSpyArg.at(2)), set1);
@@ -740,24 +714,24 @@ void tst_QBarSeries::mousehovered()
 // move mouse to center of set1
     QTest::mouseMove(view.viewport(), layout.at(0).center().toPoint());
     QTest::qWait(5000);
-    QCOMPARE(seriesIndexSpy.count(), 0);
-    QCOMPARE(setIndexSpy1.count(), 0);
-    QCOMPARE(setIndexSpy2.count(), 0);
+    QCOMPARE(seriesIndexSpy.size(), 0);
+    QCOMPARE(setIndexSpy1.size(), 0);
+    QCOMPARE(setIndexSpy2.size(), 0);
 
 //=======================================================================
 // move mouse to bottom of set1
     QTest::mouseMove(view.viewport(), QPoint(layout.at(0).center().x(), layout.at(0).bottom()));
     QTest::qWait(5000);
-    QCOMPARE(seriesIndexSpy.count(), 0);
-    QCOMPARE(setIndexSpy1.count(), 0);
-    QCOMPARE(setIndexSpy2.count(), 0);
+    QCOMPARE(seriesIndexSpy.size(), 0);
+    QCOMPARE(setIndexSpy1.size(), 0);
+    QCOMPARE(setIndexSpy2.size(), 0);
 
 //=======================================================================
 // move mouse from top of set1 to top of set2
     QTest::mouseMove(view.viewport(), QPoint(layout.at(1).x() + 1, layout.at(1).y() + 1));
-    QTRY_COMPARE(seriesIndexSpy.count(), 2);
-    QTRY_COMPARE(setIndexSpy1.count(), 1);
-    QTRY_COMPARE(setIndexSpy2.count(), 1);
+    QTRY_COMPARE(seriesIndexSpy.size(), 2);
+    QTRY_COMPARE(setIndexSpy1.size(), 1);
+    QTRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should leave set1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -782,9 +756,9 @@ void tst_QBarSeries::mousehovered()
 //=======================================================================
 // move mouse from top of set2 to background
     QTest::mouseMove(view.viewport(), QPoint(layout.at(1).center().x(), 0));
-    QTRY_COMPARE(seriesIndexSpy.count(), 1);
-    QTRY_COMPARE(setIndexSpy1.count(), 0);
-    QTRY_COMPARE(setIndexSpy2.count(), 1);
+    QTRY_COMPARE(seriesIndexSpy.size(), 1);
+    QTRY_COMPARE(setIndexSpy1.size(), 0);
+    QTRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should leave set2
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -800,9 +774,9 @@ void tst_QBarSeries::mousehovered()
 // move mouse on top of set1, bar0 to check the index (hover into set1)
     QTest::mouseMove(view.viewport(), QPoint(layout.at(0).x() + 1, layout.at(0).y() + 1));
 
-    QTRY_COMPARE(seriesIndexSpy.count(), 1);
-    QTRY_COMPARE(setIndexSpy1.count(), 1);
-    QTRY_COMPARE(setIndexSpy2.count(), 0);
+    QTRY_COMPARE(seriesIndexSpy.size(), 1);
+    QTRY_COMPARE(setIndexSpy1.size(), 1);
+    QTRY_COMPARE(setIndexSpy2.size(), 0);
 
     //should enter set1, bar0
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -823,9 +797,9 @@ void tst_QBarSeries::mousehovered()
 // hover in set1)
     QTest::mouseMove(view.viewport(), QPoint(layout.at(1).x() + 1, layout.at(1).y() + 1));
 
-    QTRY_COMPARE(seriesIndexSpy.count(), 2);
-    QTRY_COMPARE(setIndexSpy1.count(), 1);
-    QTRY_COMPARE(setIndexSpy2.count(), 1);
+    QTRY_COMPARE(seriesIndexSpy.size(), 2);
+    QTRY_COMPARE(setIndexSpy1.size(), 1);
+    QTRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should leave set1, bar0
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -860,9 +834,9 @@ void tst_QBarSeries::mousehovered()
 // hover in set1)
     QTest::mouseMove(view.viewport(), QPoint(layout.at(2).x() + 1, layout.at(2).y() + 1));
 
-    QTRY_COMPARE(seriesIndexSpy.count(), 2);
-    QTRY_COMPARE(setIndexSpy1.count(), 1);
-    QTRY_COMPARE(setIndexSpy2.count(), 1);
+    QTRY_COMPARE(seriesIndexSpy.size(), 2);
+    QTRY_COMPARE(setIndexSpy1.size(), 1);
+    QTRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should leave set2, bar0
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -897,9 +871,9 @@ void tst_QBarSeries::mousehovered()
 // (hover out set1)
     QTest::mouseMove(view.viewport(), QPoint((layout.at(2).right() + layout.at(3).left()) / 2, 0));
 
-    QTRY_COMPARE(seriesIndexSpy.count(), 1);
-    QTRY_COMPARE(setIndexSpy1.count(), 1);
-    QTRY_COMPARE(setIndexSpy2.count(), 0);
+    QTRY_COMPARE(seriesIndexSpy.size(), 1);
+    QTRY_COMPARE(setIndexSpy1.size(), 1);
+    QTRY_COMPARE(setIndexSpy2.size(), 0);
 
     // should leave set1, bar1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -919,9 +893,9 @@ void tst_QBarSeries::mousehovered()
 // move mouse on top of set2, bar1 to check the index (hover in set2)
     QTest::mouseMove(view.viewport(), QPoint(layout.at(3).x() + 1, layout.at(3).y() + 1));
 
-    QTRY_COMPARE(seriesIndexSpy.count(), 1);
-    QTRY_COMPARE(setIndexSpy1.count(), 0);
-    QTRY_COMPARE(setIndexSpy2.count(), 1);
+    QTRY_COMPARE(seriesIndexSpy.size(), 1);
+    QTRY_COMPARE(setIndexSpy1.size(), 0);
+    QTRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should enter set2, bar1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -942,9 +916,9 @@ void tst_QBarSeries::mousehovered()
 //(hover out set2)
     QTest::mouseMove(view.viewport(), QPoint((layout.at(3).right() + layout.at(3).left()) / 2, 0));
 
-    QTRY_COMPARE(seriesIndexSpy.count(), 1);
-    QTRY_COMPARE(setIndexSpy1.count(), 0);
-    QTRY_COMPARE(setIndexSpy2.count(), 1);
+    QTRY_COMPARE(seriesIndexSpy.size(), 1);
+    QTRY_COMPARE(setIndexSpy1.size(), 0);
+    QTRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should leave set2, bar1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -994,7 +968,7 @@ void tst_QBarSeries::destruction()
     delete series;
 
     // check that series deletes the set
-    QCOMPARE(spy1.count(), 1);
+    QCOMPARE(spy1.size(), 1);
 }
 
 void tst_QBarSeries::mousePressed()
@@ -1058,9 +1032,9 @@ void tst_QBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -1076,9 +1050,9 @@ void tst_QBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -1094,9 +1068,9 @@ void tst_QBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(4).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -1112,9 +1086,9 @@ void tst_QBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -1130,9 +1104,9 @@ void tst_QBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(3).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -1148,9 +1122,9 @@ void tst_QBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(5).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -1223,9 +1197,9 @@ void tst_QBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -1241,9 +1215,9 @@ void tst_QBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -1259,9 +1233,9 @@ void tst_QBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(4).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -1277,9 +1251,9 @@ void tst_QBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -1295,9 +1269,9 @@ void tst_QBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(3).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -1313,9 +1287,9 @@ void tst_QBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(5).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -1387,9 +1361,9 @@ void tst_QBarSeries::mouseDoubleClicked()
     QTest::mouseDClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
